diff --git a/LNBolt.Tests/LNBolt.Tests.csproj b/LNBolt.Tests/LNBolt.Tests.csproj
index 10aa3df..79773a0 100644
--- a/LNBolt.Tests/LNBolt.Tests.csproj
+++ b/LNBolt.Tests/LNBolt.Tests.csproj
@@ -13,7 +13,7 @@
-
+
all
runtime; build; native; contentfiles; analyzers; buildtransitive
diff --git a/LNUnit.LND/LNUnit.LND.csproj b/LNUnit.LND/LNUnit.LND.csproj
index 8eb8686..44e20db 100644
--- a/LNUnit.LND/LNUnit.LND.csproj
+++ b/LNUnit.LND/LNUnit.LND.csproj
@@ -6,7 +6,7 @@
enable
true
LNUnit.LND
- 1.6.4
+ 1.6.5
LNUnit LND Typed Clients
@@ -20,11 +20,11 @@
-
-
-
+
+
+
-
+
all
runtime; build; native; contentfiles; analyzers; buildtransitive
diff --git a/LNUnit.Tests/Abstract/AbcLightningAbstractTests.cs b/LNUnit.Tests/Abstract/AbcLightningAbstractTests.cs
index 29b29e8..452a568 100644
--- a/LNUnit.Tests/Abstract/AbcLightningAbstractTests.cs
+++ b/LNUnit.Tests/Abstract/AbcLightningAbstractTests.cs
@@ -138,7 +138,7 @@ public async Task SetupNetwork(string lndImage = "lightninglabs/lnd", string lnd
RemoteName = "bob"
}
], imageName: lndImage, tagName: lndTag, pullImage: false, acceptKeysend: true, mapTotmp: false,
- postgresDSN: _dbType == "postgres" ? PostgresFixture.LNDConnectionStrings["alice"] : null);
+ postgresDSN: _dbType == "postgres" ? PostgresFixture.LNDConnectionStrings["alice"] : null, lndkSupport:false, nativeSql: _dbType == "postgres" );
Builder.AddPolarLNDNode("bob",
[
@@ -149,7 +149,7 @@ public async Task SetupNetwork(string lndImage = "lightninglabs/lnd", string lnd
RemoteName = "alice"
}
], imageName: lndImage, tagName: lndTag, pullImage: false, acceptKeysend: true, mapTotmp: false,
- postgresDSN: _dbType == "postgres" ? PostgresFixture.LNDConnectionStrings["bob"] : null);
+ postgresDSN: _dbType == "postgres" ? PostgresFixture.LNDConnectionStrings["bob"] : null, lndkSupport:false, nativeSql: _dbType == "postgres" );
Builder.AddPolarLNDNode("carol",
[
@@ -178,7 +178,7 @@ public async Task SetupNetwork(string lndImage = "lightninglabs/lnd", string lnd
RemoteName = "bob"
}
], imageName: lndImage, tagName: lndTag, pullImage: false, acceptKeysend: true, mapTotmp: false,
- postgresDSN: _dbType == "postgres" ? PostgresFixture.LNDConnectionStrings["carol"] : null);
+ postgresDSN: _dbType == "postgres" ? PostgresFixture.LNDConnectionStrings["carol"] : null, lndkSupport:false, nativeSql: _dbType == "postgres" );
await Builder.Build(lndRoot: lndRoot);
@@ -1007,7 +1007,10 @@ public async Task ListInvoiceAndPaymentPaging()
var bob = await Builder.WaitUntilAliasIsServerReady("bob");
//purge data
- await bob.LightningClient.DeleteAllPaymentsAsync(new DeleteAllPaymentsRequest());
+ await bob.LightningClient.DeleteAllPaymentsAsync(new DeleteAllPaymentsRequest()
+ {
+ AllPayments = true
+ });
foreach (var invoice in invoices)
{
@@ -1015,7 +1018,7 @@ public async Task ListInvoiceAndPaymentPaging()
{
PaymentRequest = invoice.PaymentRequest,
FeeLimitSat = 100000000,
- TimeoutSeconds = 50
+ TimeoutSeconds = 50,
});
Assert.That(payment.Status == Payment.Types.PaymentStatus.Succeeded);
}
diff --git a/LNUnit.Tests/LNUnit.Tests.csproj b/LNUnit.Tests/LNUnit.Tests.csproj
index 6b6f44e..de805b6 100644
--- a/LNUnit.Tests/LNUnit.Tests.csproj
+++ b/LNUnit.Tests/LNUnit.Tests.csproj
@@ -13,12 +13,12 @@
-
-
-
+
+
+
-
+
@@ -32,7 +32,7 @@
-
+
diff --git a/LNUnit/LNUnit.csproj b/LNUnit/LNUnit.csproj
index 4492c61..b87f658 100644
--- a/LNUnit/LNUnit.csproj
+++ b/LNUnit/LNUnit.csproj
@@ -5,7 +5,7 @@
enable
enable
Linux
- 1.6.4
+ 1.6.5
true
LNUnit
Lightning Network Unit Testing Framework
diff --git a/LNUnit/Setup/LNUnitBuilder.cs b/LNUnit/Setup/LNUnitBuilder.cs
index ed7d3b1..f750cd0 100644
--- a/LNUnit/Setup/LNUnitBuilder.cs
+++ b/LNUnit/Setup/LNUnitBuilder.cs
@@ -914,7 +914,8 @@ public static LNUnitBuilder AddPolarLNDNode(this LNUnitBuilder b, string aliasHo
List? channels = null, string bitcoinMinerHost = "miner",
string rpcUser = "bitcoin", string rpcPass = "bitcoin", string imageName = "polarlightning/lnd",
string tagName = "0.17.4-beta", bool acceptKeysend = true, bool pullImage = true, bool mapTotmp = false,
- bool gcInvoiceOnStartup = false, bool gcInvoiceOnFly = false, string? postgresDSN = null, string lndRoot = "/home/lnd/.lnd")
+ bool gcInvoiceOnStartup = false, bool gcInvoiceOnFly = false, string? postgresDSN = null,
+ string lndRoot = "/home/lnd/.lnd", bool lndkSupport = false, bool nativeSql = false)
{
var cmd = new List
{
@@ -942,6 +943,17 @@ public static LNUnitBuilder AddPolarLNDNode(this LNUnitBuilder b, string aliasHo
"--gossip.max-channel-update-burst=100",
"--gossip.channel-update-interval=1s"
};
+ // if (nativeSql)
+ // {
+ // cmd.Add("--db.use-native-sql");
+ //
+ // }
+ if (lndkSupport) //TODO: must compile LND with 'dev' flags before can play with this
+ {
+ cmd.Add("--protocol.custom-message=513");
+ cmd.Add("--protocol.custom-nodeann=39");
+ cmd.Add("--protocol.custom-init=39");
+ }
if (!postgresDSN.IsEmpty())
{
diff --git a/LNUnit.LND/Grpc/walletrpc/walletkit.proto b/LNUnit.LND/Grpc/walletrpc/walletkit.proto
index b6d09c6..b861803 100644
--- a/LNUnit.LND/Grpc/walletrpc/walletkit.proto
+++ b/LNUnit.LND/Grpc/walletrpc/walletkit.proto
@@ -283,7 +283,7 @@ service WalletKit {
/* lncli: `wallet labeltx`
LabelTransaction adds a label to a transaction. If the transaction already
has a label the call will fail unless the overwrite bool is set. This will
- overwrite the exiting transaction label. Labels must not be empty, and
+ overwrite the existing transaction label. Labels must not be empty, and
cannot exceed 500 characters.
*/
rpc LabelTransaction (LabelTransactionRequest)
@@ -1176,7 +1176,7 @@ message BumpFeeRequest {
// Optional. The deadline in number of blocks that the input should be spent
// within. When not set, for new inputs, the default value (1008) is used;
// for exiting inputs, their current values will be retained.
uint32 target_conf = 2;
/*
@@ -1176,7 +1176,7 @@ message BumpFeeRequest {
// Optional. The deadline in number of blocks that the input should be spent
// within. When not set, for new inputs, the default value (1008) is used;
- // for exiting inputs, their current values will be retained.
+ // for existing inputs, their current values will be retained.
uint32 target_conf = 2;
/*